# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/onlinefeaturestored/v1/onlinefeaturestored.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWgithub.com/metaprov/modelaapi/services/onlinefeaturestored/v1/onlinefeaturestored.proto\x12=github.com.metaprov.modelaapi.services.onlinefeaturestored.v1\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"|\n\x05Value\x12\x0f\n\x05int64\x18\x01 \x01(\x03H\x00\x12\x10\n\x06\x64ouble\x18\x02 \x01(\x01H\x00\x12\x10\n\x06string\x18\x03 \x01(\tH\x00\x12\x0e\n\x04\x62ool\x18\x04 \x01(\x08H\x00\x12\x14\n\nunix_milli\x18\x05 \x01(\x03H\x00\x12\x0f\n\x05\x62ytes\x18\x06 \x01(\x0cH\x00\x42\x07\n\x05value\"z\n\x10OnlineGetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12S\n\x04rows\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetRow\";\n\x08\x46GFields\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08keyvalue\x18\x02 \x01(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x03 \x03(\t\"a\n\x06GetRow\x12W\n\x06groups\x18\x01 \x03(\x0b\x32G.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.FGFields\"\x8a\x02\n\x0cGetRowResult\x12\x0f\n\x07keyname\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12g\n\x06values\x18\x03 \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetRowResult.ValuesEntry\x1as\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12S\n\x05value\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.Value:\x02\x38\x01\"n\n\x11OnlineGetResponse\x12Y\n\x04rows\x18\x01 \x03(\x0b\x32K.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetRowResult\"A\n\x03Row\x12\x0f\n\x07keyname\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05\x66ield\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\"r\n\x0bPushRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12P\n\x04rows\x18\x03 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.Row\"\x0e\n\x0cPushResponse2\xf2\x02\n\x19OnlineFeatureStoreService\x12\xb0\x01\n\tOnlineGet\x12O.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineGetRequest\x1aP.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineGetResponse\"\x00\x12\xa1\x01\n\x04Push\x12J.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.PushRequest\x1aK.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.PushResponse\"\x00\x42?Z=github.com/metaprov/modelaapi/services/onlinefeaturestored/v1b\x06proto3')



_VALUE = DESCRIPTOR.message_types_by_name['Value']
_ONLINEGETREQUEST = DESCRIPTOR.message_types_by_name['OnlineGetRequest']
_FGFIELDS = DESCRIPTOR.message_types_by_name['FGFields']
_GETROW = DESCRIPTOR.message_types_by_name['GetRow']
_GETROWRESULT = DESCRIPTOR.message_types_by_name['GetRowResult']
_GETROWRESULT_VALUESENTRY = _GETROWRESULT.nested_types_by_name['ValuesEntry']
_ONLINEGETRESPONSE = DESCRIPTOR.message_types_by_name['OnlineGetResponse']
_ROW = DESCRIPTOR.message_types_by_name['Row']
_PUSHREQUEST = DESCRIPTOR.message_types_by_name['PushRequest']
_PUSHRESPONSE = DESCRIPTOR.message_types_by_name['PushResponse']
Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
  'DESCRIPTOR' : _VALUE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.Value)
  })
_sym_db.RegisterMessage(Value)

OnlineGetRequest = _reflection.GeneratedProtocolMessageType('OnlineGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _ONLINEGETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineGetRequest)
  })
_sym_db.RegisterMessage(OnlineGetRequest)

FGFields = _reflection.GeneratedProtocolMessageType('FGFields', (_message.Message,), {
  'DESCRIPTOR' : _FGFIELDS,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.FGFields)
  })
_sym_db.RegisterMessage(FGFields)

GetRow = _reflection.GeneratedProtocolMessageType('GetRow', (_message.Message,), {
  'DESCRIPTOR' : _GETROW,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetRow)
  })
_sym_db.RegisterMessage(GetRow)

GetRowResult = _reflection.GeneratedProtocolMessageType('GetRowResult', (_message.Message,), {

  'ValuesEntry' : _reflection.GeneratedProtocolMessageType('ValuesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETROWRESULT_VALUESENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetRowResult.ValuesEntry)
    })
  ,
  'DESCRIPTOR' : _GETROWRESULT,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetRowResult)
  })
_sym_db.RegisterMessage(GetRowResult)
_sym_db.RegisterMessage(GetRowResult.ValuesEntry)

OnlineGetResponse = _reflection.GeneratedProtocolMessageType('OnlineGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _ONLINEGETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineGetResponse)
  })
_sym_db.RegisterMessage(OnlineGetResponse)

Row = _reflection.GeneratedProtocolMessageType('Row', (_message.Message,), {
  'DESCRIPTOR' : _ROW,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.Row)
  })
_sym_db.RegisterMessage(Row)

PushRequest = _reflection.GeneratedProtocolMessageType('PushRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUSHREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.PushRequest)
  })
_sym_db.RegisterMessage(PushRequest)

PushResponse = _reflection.GeneratedProtocolMessageType('PushResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUSHRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.PushResponse)
  })
_sym_db.RegisterMessage(PushResponse)

_ONLINEFEATURESTORESERVICE = DESCRIPTOR.services_by_name['OnlineFeatureStoreService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z=github.com/metaprov/modelaapi/services/onlinefeaturestored/v1'
  _GETROWRESULT_VALUESENTRY._options = None
  _GETROWRESULT_VALUESENTRY._serialized_options = b'8\001'
  _VALUE._serialized_start=369
  _VALUE._serialized_end=493
  _ONLINEGETREQUEST._serialized_start=495
  _ONLINEGETREQUEST._serialized_end=617
  _FGFIELDS._serialized_start=619
  _FGFIELDS._serialized_end=678
  _GETROW._serialized_start=680
  _GETROW._serialized_end=777
  _GETROWRESULT._serialized_start=780
  _GETROWRESULT._serialized_end=1046
  _GETROWRESULT_VALUESENTRY._serialized_start=931
  _GETROWRESULT_VALUESENTRY._serialized_end=1046
  _ONLINEGETRESPONSE._serialized_start=1048
  _ONLINEGETRESPONSE._serialized_end=1158
  _ROW._serialized_start=1160
  _ROW._serialized_end=1225
  _PUSHREQUEST._serialized_start=1227
  _PUSHREQUEST._serialized_end=1341
  _PUSHRESPONSE._serialized_start=1343
  _PUSHRESPONSE._serialized_end=1357
  _ONLINEFEATURESTORESERVICE._serialized_start=1360
  _ONLINEFEATURESTORESERVICE._serialized_end=1730
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/dataproductversion/v1/dataproductversion.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUgithub.com/metaprov/modelaapi/services/dataproductversion/v1/dataproductversion.proto\x12<github.com.metaprov.modelaapi.services.dataproductversion.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\x95\x02\n\x1eListDataProductVersionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12x\n\x06labels\x18\x02 \x03(\x0b\x32h.github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa5\x01\n\x1fListDataProductVersionsResponse\x12i\n\x13\x64\x61taproductversions\x18\x01 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersionList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x87\x01\n\x1f\x43reateDataProductVersionRequest\x12\x64\n\x12\x64\x61taproductversion\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"\"\n CreateDataProductVersionResponse\"\xb7\x01\n\x1fUpdateDataProductVersionRequest\x12\x64\n\x12\x64\x61taproductversion\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\"\n UpdateDataProductVersionResponse\"?\n\x1cGetDataProductVersionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x93\x01\n\x1dGetDataProductVersionResponse\x12\x64\n\x12\x64\x61taproductversion\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"B\n\x1f\x44\x65leteDataProductVersionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\"\n DeleteDataProductVersionResponse2\x83\x0b\n\x19\x44\x61taProductVersionService\x12\x83\x02\n\x17ListDataProductVersions\x12\\.github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsRequest\x1a].github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/v1/dataproductversions/{namespace}\x12\xfd\x01\n\x18\x43reateDataProductVersion\x12].github.com.metaprov.modelaapi.services.dataproductversion.v1.CreateDataProductVersionRequest\x1a^.github.com.metaprov.modelaapi.services.dataproductversion.v1.CreateDataProductVersionResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/dataproductversions:\x01*\x12\x84\x02\n\x15GetDataProductVersion\x12Z.github.com.metaprov.modelaapi.services.dataproductversion.v1.GetDataProductVersionRequest\x1a[.github.com.metaprov.modelaapi.services.dataproductversion.v1.GetDataProductVersionResponse\"2\x82\xd3\xe4\x93\x02,\x12*/v1/dataproductversions/{namespace}/{name}\x12\xc8\x02\n\x18UpdateDataProductVersion\x12].github.com.metaprov.modelaapi.services.dataproductversion.v1.UpdateDataProductVersionRequest\x1a^.github.com.metaprov.modelaapi.services.dataproductversion.v1.UpdateDataProductVersionResponse\"m\x82\xd3\xe4\x93\x02g\x1a\x62/v1/dataproductversions/{dataproductversion.metadata.namespace}/{dataproductversion.metadata.name}:\x01*\x12\x8d\x02\n\x18\x44\x65leteDataProductVersion\x12].github.com.metaprov.modelaapi.services.dataproductversion.v1.DeleteDataProductVersionRequest\x1a^.github.com.metaprov.modelaapi.services.dataproductversion.v1.DeleteDataProductVersionResponse\"2\x82\xd3\xe4\x93\x02,**/v1/dataproductversions/{namespace}/{name}B>Z<github.com/metaprov/modelaapi/services/dataproductversion/v1b\x06proto3')



_LISTDATAPRODUCTVERSIONSREQUEST = DESCRIPTOR.message_types_by_name['ListDataProductVersionsRequest']
_LISTDATAPRODUCTVERSIONSREQUEST_LABELSENTRY = _LISTDATAPRODUCTVERSIONSREQUEST.nested_types_by_name['LabelsEntry']
_LISTDATAPRODUCTVERSIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListDataProductVersionsResponse']
_CREATEDATAPRODUCTVERSIONREQUEST = DESCRIPTOR.message_types_by_name['CreateDataProductVersionRequest']
_CREATEDATAPRODUCTVERSIONRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataProductVersionResponse']
_UPDATEDATAPRODUCTVERSIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataProductVersionRequest']
_UPDATEDATAPRODUCTVERSIONRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataProductVersionResponse']
_GETDATAPRODUCTVERSIONREQUEST = DESCRIPTOR.message_types_by_name['GetDataProductVersionRequest']
_GETDATAPRODUCTVERSIONRESPONSE = DESCRIPTOR.message_types_by_name['GetDataProductVersionResponse']
_DELETEDATAPRODUCTVERSIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataProductVersionRequest']
_DELETEDATAPRODUCTVERSIONRESPONSE = DESCRIPTOR.message_types_by_name['DeleteDataProductVersionResponse']
ListDataProductVersionsRequest = _reflection.GeneratedProtocolMessageType('ListDataProductVersionsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATAPRODUCTVERSIONSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATAPRODUCTVERSIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsRequest)
  })
_sym_db.RegisterMessage(ListDataProductVersionsRequest)
_sym_db.RegisterMessage(ListDataProductVersionsRequest.LabelsEntry)

ListDataProductVersionsResponse = _reflection.GeneratedProtocolMessageType('ListDataProductVersionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTVERSIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.ListDataProductVersionsResponse)
  })
_sym_db.RegisterMessage(ListDataProductVersionsResponse)

CreateDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('CreateDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.CreateDataProductVersionRequest)
  })
_sym_db.RegisterMessage(CreateDataProductVersionRequest)

CreateDataProductVersionResponse = _reflection.GeneratedProtocolMessageType('CreateDataProductVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPRODUCTVERSIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.CreateDataProductVersionResponse)
  })
_sym_db.RegisterMessage(CreateDataProductVersionResponse)

UpdateDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('UpdateDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.UpdateDataProductVersionRequest)
  })
_sym_db.RegisterMessage(UpdateDataProductVersionRequest)

UpdateDataProductVersionResponse = _reflection.GeneratedProtocolMessageType('UpdateDataProductVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPRODUCTVERSIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.UpdateDataProductVersionResponse)
  })
_sym_db.RegisterMessage(UpdateDataProductVersionResponse)

GetDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('GetDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.GetDataProductVersionRequest)
  })
_sym_db.RegisterMessage(GetDataProductVersionRequest)

GetDataProductVersionResponse = _reflection.GeneratedProtocolMessageType('GetDataProductVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPRODUCTVERSIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.GetDataProductVersionResponse)
  })
_sym_db.RegisterMessage(GetDataProductVersionResponse)

DeleteDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('DeleteDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.DeleteDataProductVersionRequest)
  })
_sym_db.RegisterMessage(DeleteDataProductVersionRequest)

DeleteDataProductVersionResponse = _reflection.GeneratedProtocolMessageType('DeleteDataProductVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPRODUCTVERSIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproductversion.v1.dataproductversion_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproductversion.v1.DeleteDataProductVersionResponse)
  })
_sym_db.RegisterMessage(DeleteDataProductVersionResponse)

_DATAPRODUCTVERSIONSERVICE = DESCRIPTOR.services_by_name['DataProductVersionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z<github.com/metaprov/modelaapi/services/dataproductversion/v1'
  _LISTDATAPRODUCTVERSIONSREQUEST_LABELSENTRY._options = None
  _LISTDATAPRODUCTVERSIONSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _DATAPRODUCTVERSIONSERVICE.methods_by_name['ListDataProductVersions']._options = None
  _DATAPRODUCTVERSIONSERVICE.methods_by_name['ListDataProductVersions']._serialized_options = b'\202\323\344\223\002%\022#/v1/dataproductversions/{namespace}'
  _DATAPRODUCTVERSIONSERVICE.methods_by_name['CreateDataProductVersion']._options = None
  _DATAPRODUCTVERSIONSERVICE.methods_by_name['CreateDataProductVersion']._serialized_options = b'\202\323\344\223\002\034\"\027/v1/dataproductversions:\001*'
  _DATAPRODUCTVERSIONSERVICE.methods_by_name['GetDataProductVersion']._options = None
  _DATAPRODUCTVERSIONSERVICE.methods_by_name['GetDataProductVersion']._serialized_options = b'\202\323\344\223\002,\022*/v1/dataproductversions/{namespace}/{name}'
  _DATAPRODUCTVERSIONSERVICE.methods_by_name['UpdateDataProductVersion']._options = None
  _DATAPRODUCTVERSIONSERVICE.methods_by_name['UpdateDataProductVersion']._serialized_options = b'\202\323\344\223\002g\032b/v1/dataproductversions/{dataproductversion.metadata.namespace}/{dataproductversion.metadata.name}:\001*'
  _DATAPRODUCTVERSIONSERVICE.methods_by_name['DeleteDataProductVersion']._options = None
  _DATAPRODUCTVERSIONSERVICE.methods_by_name['DeleteDataProductVersion']._serialized_options = b'\202\323\344\223\002,**/v1/dataproductversions/{namespace}/{name}'
  _LISTDATAPRODUCTVERSIONSREQUEST._serialized_start=349
  _LISTDATAPRODUCTVERSIONSREQUEST._serialized_end=626
  _LISTDATAPRODUCTVERSIONSREQUEST_LABELSENTRY._serialized_start=581
  _LISTDATAPRODUCTVERSIONSREQUEST_LABELSENTRY._serialized_end=626
  _LISTDATAPRODUCTVERSIONSRESPONSE._serialized_start=629
  _LISTDATAPRODUCTVERSIONSRESPONSE._serialized_end=794
  _CREATEDATAPRODUCTVERSIONREQUEST._serialized_start=797
  _CREATEDATAPRODUCTVERSIONREQUEST._serialized_end=932
  _CREATEDATAPRODUCTVERSIONRESPONSE._serialized_start=934
  _CREATEDATAPRODUCTVERSIONRESPONSE._serialized_end=968
  _UPDATEDATAPRODUCTVERSIONREQUEST._serialized_start=971
  _UPDATEDATAPRODUCTVERSIONREQUEST._serialized_end=1154
  _UPDATEDATAPRODUCTVERSIONRESPONSE._serialized_start=1156
  _UPDATEDATAPRODUCTVERSIONRESPONSE._serialized_end=1190
  _GETDATAPRODUCTVERSIONREQUEST._serialized_start=1192
  _GETDATAPRODUCTVERSIONREQUEST._serialized_end=1255
  _GETDATAPRODUCTVERSIONRESPONSE._serialized_start=1258
  _GETDATAPRODUCTVERSIONRESPONSE._serialized_end=1405
  _DELETEDATAPRODUCTVERSIONREQUEST._serialized_start=1407
  _DELETEDATAPRODUCTVERSIONREQUEST._serialized_end=1473
  _DELETEDATAPRODUCTVERSIONRESPONSE._serialized_start=1475
  _DELETEDATAPRODUCTVERSIONRESPONSE._serialized_end=1509
  _DATAPRODUCTVERSIONSERVICE._serialized_start=1512
  _DATAPRODUCTVERSIONSERVICE._serialized_end=2923
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/servingsite/v1/servingsite.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGgithub.com/metaprov/modelaapi/services/servingsite/v1/servingsite.proto\x12\x35github.com.metaprov.modelaapi.services.servingsite.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"\x80\x02\n\x17ListServingSitesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12j\n\x06labels\x18\x02 \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x91\x01\n\x18ListServingSitesResponse\x12\\\n\x0cservingsites\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSiteList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"s\n\x18\x43reateServingSiteRequest\x12W\n\x0bservingsite\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"\x1b\n\x19\x43reateServingSiteResponse\"\xa3\x01\n\x18UpdateServingSiteRequest\x12W\n\x0bservingsite\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1b\n\x19UpdateServingSiteResponse\"8\n\x15GetServingSiteRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x7f\n\x16GetServingSiteResponse\x12W\n\x0bservingsite\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"6\n\x13GetPublicKeyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\")\n\x14GetPublicKeyResponse\x12\x11\n\tpublickey\x18\x01 \x01(\x0c\";\n\x18\x44\x65leteServingSiteRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1b\n\x19\x44\x65leteServingSiteResponse2\x80\x0b\n\x12ServingSiteService\x12\xd9\x01\n\x10ListServingSites\x12N.github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesRequest\x1aO.github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/servingsites/{namespace}\x12\xd3\x01\n\x11\x43reateServingSite\x12O.github.com.metaprov.modelaapi.services.servingsite.v1.CreateServingSiteRequest\x1aP.github.com.metaprov.modelaapi.services.servingsite.v1.CreateServingSiteResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/servingsites:\x01*\x12\xda\x01\n\x0eGetServingSite\x12L.github.com.metaprov.modelaapi.services.servingsite.v1.GetServingSiteRequest\x1aM.github.com.metaprov.modelaapi.services.servingsite.v1.GetServingSiteResponse\"+\x82\xd3\xe4\x93\x02%\x12#/v1/servingsites/{namespace}/{name}\x12\x90\x02\n\x11UpdateServingSite\x12O.github.com.metaprov.modelaapi.services.servingsite.v1.UpdateServingSiteRequest\x1aP.github.com.metaprov.modelaapi.services.servingsite.v1.UpdateServingSiteResponse\"X\x82\xd3\xe4\x93\x02R\x1aM/v1/servingsites/{servingsite.metadata.namespace}/{servingsite.metadata.name}:\x01*\x12\xe3\x01\n\x11\x44\x65leteServingSite\x12O.github.com.metaprov.modelaapi.services.servingsite.v1.DeleteServingSiteRequest\x1aP.github.com.metaprov.modelaapi.services.servingsite.v1.DeleteServingSiteResponse\"+\x82\xd3\xe4\x93\x02%*#/v1/servingsites/{namespace}/{name}\x12\xe1\x01\n\x0cGetPublicKey\x12J.github.com.metaprov.modelaapi.services.servingsite.v1.GetPublicKeyRequest\x1aK.github.com.metaprov.modelaapi.services.servingsite.v1.GetPublicKeyResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v1/servingsites/{namespace}/{name}:getpublickeyB7Z5github.com/metaprov/modelaapi/services/servingsite/v1b\x06proto3')



_LISTSERVINGSITESREQUEST = DESCRIPTOR.message_types_by_name['ListServingSitesRequest']
_LISTSERVINGSITESREQUEST_LABELSENTRY = _LISTSERVINGSITESREQUEST.nested_types_by_name['LabelsEntry']
_LISTSERVINGSITESRESPONSE = DESCRIPTOR.message_types_by_name['ListServingSitesResponse']
_CREATESERVINGSITEREQUEST = DESCRIPTOR.message_types_by_name['CreateServingSiteRequest']
_CREATESERVINGSITERESPONSE = DESCRIPTOR.message_types_by_name['CreateServingSiteResponse']
_UPDATESERVINGSITEREQUEST = DESCRIPTOR.message_types_by_name['UpdateServingSiteRequest']
_UPDATESERVINGSITERESPONSE = DESCRIPTOR.message_types_by_name['UpdateServingSiteResponse']
_GETSERVINGSITEREQUEST = DESCRIPTOR.message_types_by_name['GetServingSiteRequest']
_GETSERVINGSITERESPONSE = DESCRIPTOR.message_types_by_name['GetServingSiteResponse']
_GETPUBLICKEYREQUEST = DESCRIPTOR.message_types_by_name['GetPublicKeyRequest']
_GETPUBLICKEYRESPONSE = DESCRIPTOR.message_types_by_name['GetPublicKeyResponse']
_DELETESERVINGSITEREQUEST = DESCRIPTOR.message_types_by_name['DeleteServingSiteRequest']
_DELETESERVINGSITERESPONSE = DESCRIPTOR.message_types_by_name['DeleteServingSiteResponse']
ListServingSitesRequest = _reflection.GeneratedProtocolMessageType('ListServingSitesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSERVINGSITESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSERVINGSITESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesRequest)
  })
_sym_db.RegisterMessage(ListServingSitesRequest)
_sym_db.RegisterMessage(ListServingSitesRequest.LabelsEntry)

ListServingSitesResponse = _reflection.GeneratedProtocolMessageType('ListServingSitesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVINGSITESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.ListServingSitesResponse)
  })
_sym_db.RegisterMessage(ListServingSitesResponse)

CreateServingSiteRequest = _reflection.GeneratedProtocolMessageType('CreateServingSiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.CreateServingSiteRequest)
  })
_sym_db.RegisterMessage(CreateServingSiteRequest)

CreateServingSiteResponse = _reflection.GeneratedProtocolMessageType('CreateServingSiteResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVINGSITERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.CreateServingSiteResponse)
  })
_sym_db.RegisterMessage(CreateServingSiteResponse)

UpdateServingSiteRequest = _reflection.GeneratedProtocolMessageType('UpdateServingSiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.UpdateServingSiteRequest)
  })
_sym_db.RegisterMessage(UpdateServingSiteRequest)

UpdateServingSiteResponse = _reflection.GeneratedProtocolMessageType('UpdateServingSiteResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESERVINGSITERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.UpdateServingSiteResponse)
  })
_sym_db.RegisterMessage(UpdateServingSiteResponse)

GetServingSiteRequest = _reflection.GeneratedProtocolMessageType('GetServingSiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.GetServingSiteRequest)
  })
_sym_db.RegisterMessage(GetServingSiteRequest)

GetServingSiteResponse = _reflection.GeneratedProtocolMessageType('GetServingSiteResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVINGSITERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.GetServingSiteResponse)
  })
_sym_db.RegisterMessage(GetServingSiteResponse)

GetPublicKeyRequest = _reflection.GeneratedProtocolMessageType('GetPublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPUBLICKEYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.GetPublicKeyRequest)
  })
_sym_db.RegisterMessage(GetPublicKeyRequest)

GetPublicKeyResponse = _reflection.GeneratedProtocolMessageType('GetPublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPUBLICKEYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.GetPublicKeyResponse)
  })
_sym_db.RegisterMessage(GetPublicKeyResponse)

DeleteServingSiteRequest = _reflection.GeneratedProtocolMessageType('DeleteServingSiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.DeleteServingSiteRequest)
  })
_sym_db.RegisterMessage(DeleteServingSiteRequest)

DeleteServingSiteResponse = _reflection.GeneratedProtocolMessageType('DeleteServingSiteResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESERVINGSITERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.servingsite.v1.servingsite_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.DeleteServingSiteResponse)
  })
_sym_db.RegisterMessage(DeleteServingSiteResponse)

_SERVINGSITESERVICE = DESCRIPTOR.services_by_name['ServingSiteService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/metaprov/modelaapi/services/servingsite/v1'
  _LISTSERVINGSITESREQUEST_LABELSENTRY._options = None
  _LISTSERVINGSITESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _SERVINGSITESERVICE.methods_by_name['ListServingSites']._options = None
  _SERVINGSITESERVICE.methods_by_name['ListServingSites']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/servingsites/{namespace}'
  _SERVINGSITESERVICE.methods_by_name['CreateServingSite']._options = None
  _SERVINGSITESERVICE.methods_by_name['CreateServingSite']._serialized_options = b'\202\323\344\223\002\025\"\020/v1/servingsites:\001*'
  _SERVINGSITESERVICE.methods_by_name['GetServingSite']._options = None
  _SERVINGSITESERVICE.methods_by_name['GetServingSite']._serialized_options = b'\202\323\344\223\002%\022#/v1/servingsites/{namespace}/{name}'
  _SERVINGSITESERVICE.methods_by_name['UpdateServingSite']._options = None
  _SERVINGSITESERVICE.methods_by_name['UpdateServingSite']._serialized_options = b'\202\323\344\223\002R\032M/v1/servingsites/{servingsite.metadata.namespace}/{servingsite.metadata.name}:\001*'
  _SERVINGSITESERVICE.methods_by_name['DeleteServingSite']._options = None
  _SERVINGSITESERVICE.methods_by_name['DeleteServingSite']._serialized_options = b'\202\323\344\223\002%*#/v1/servingsites/{namespace}/{name}'
  _SERVINGSITESERVICE.methods_by_name['GetPublicKey']._options = None
  _SERVINGSITESERVICE.methods_by_name['GetPublicKey']._serialized_options = b'\202\323\344\223\0022\0220/v1/servingsites/{namespace}/{name}:getpublickey'
  _LISTSERVINGSITESREQUEST._serialized_start=266
  _LISTSERVINGSITESREQUEST._serialized_end=522
  _LISTSERVINGSITESREQUEST_LABELSENTRY._serialized_start=477
  _LISTSERVINGSITESREQUEST_LABELSENTRY._serialized_end=522
  _LISTSERVINGSITESRESPONSE._serialized_start=525
  _LISTSERVINGSITESRESPONSE._serialized_end=670
  _CREATESERVINGSITEREQUEST._serialized_start=672
  _CREATESERVINGSITEREQUEST._serialized_end=787
  _CREATESERVINGSITERESPONSE._serialized_start=789
  _CREATESERVINGSITERESPONSE._serialized_end=816
  _UPDATESERVINGSITEREQUEST._serialized_start=819
  _UPDATESERVINGSITEREQUEST._serialized_end=982
  _UPDATESERVINGSITERESPONSE._serialized_start=984
  _UPDATESERVINGSITERESPONSE._serialized_end=1011
  _GETSERVINGSITEREQUEST._serialized_start=1013
  _GETSERVINGSITEREQUEST._serialized_end=1069
  _GETSERVINGSITERESPONSE._serialized_start=1071
  _GETSERVINGSITERESPONSE._serialized_end=1198
  _GETPUBLICKEYREQUEST._serialized_start=1200
  _GETPUBLICKEYREQUEST._serialized_end=1254
  _GETPUBLICKEYRESPONSE._serialized_start=1256
  _GETPUBLICKEYRESPONSE._serialized_end=1297
  _DELETESERVINGSITEREQUEST._serialized_start=1299
  _DELETESERVINGSITEREQUEST._serialized_end=1358
  _DELETESERVINGSITERESPONSE._serialized_start=1360
  _DELETESERVINGSITERESPONSE._serialized_end=1387
  _SERVINGSITESERVICE._serialized_start=1390
  _SERVINGSITESERVICE._serialized_end=2798
# @@protoc_insertion_point(module_scope)




##############################################################
# Imports
##############################################################
from typing import Dict

import numpy as np
import pandas as pd
import sklearn
from typing import Tuple
from statsmodels.tsa.stattools import kpss, adfuller
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2 import DataSource
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2 import Study, Model

from modelaapi import consts

class MTimeSeries:
    """
    Representation of the pastime series.
    """

    def __init__(
            self,
            data_source:DataSource,
            study:Study = None,
            model:Model = None,
            data: pd.DataFrame = None,
    ):
        self.__df: pd.DataFrame = data
        self.__study = study # Note that the study can be null,for example when we analyze the dataset.
        self.__datasource = data_source
        self.__model = model
        # Future data frams
        self.__y_point_forecast = None # Hold the point forecast
        self.__y_quantile_forecast = None  # Hold the quantile forecast
        self.__y_range_forecast = None  # Hold the range forecast
        self.__y_train = None  # Hold the forecast on this data frame
        self.__y_test = None  # Hold the forecast on this data frame
        self.__y_test_forecast = None  # Hold the forecast model only on the training data.
        self.__scores = []

    ###########################################################################
    # Data Source Fields
    ###########################################################################

    @property
    def interval(self):
        """
        Answer the time series interval.
        :return:
        """
        return self.__datasource.spec.schema.timeSeriesSchema.interval

    @property
    def freq(self):
        """
        Answer the time series interval.
        :return:
        """
        # convert
        if self.__datasource.spec.schema.timeSeriesSchema.freq == "day":
            return "D"
        if self.__datasource.spec.schema.timeSeriesSchema.freq == "month":
            return "M"
        if self.__datasource.spec.schema.timeSeriesSchema.freq == "week":
            return "W"
        if self.__datasource.spec.schema.timeSeriesSchema.freq == "year":
            return "Y"

    @property
    def is_regular(self):
        """
        Answer the time series interval.
        :return:
        """
        return self.__datasource.spec.schema.timeSeriesSchema.type == "series"



    @property
    def is_hierarchical(self):
        """
        Answer the time series interval.
        :return:
        """
        return self.__datasource.spec.schema.timeSeriesSchema.type == "hierarchical"

    @property
    def time_series_columns(self):
        """
        Compute the time series columns
        :return: the time series columns
        """
        result = []
        for x in self.__datasource.spec.schema.columns:
            if x.timeseries:
                result.append(x.name)
        return result

    @property
    def value_column_name(self):
        """
        Compute the time series columns
        :return: the time series columns
        """
        result = []
        for x in self.__datasource.spec.schema.columns:
            if x.target:
                return x.name

        raise ValueError("no value column defined, please set the target attribute to True on the target column")

    @property
    def time_column_name(self):
        """
        return the time series index column name
        :return: the time series columns
        """
        for x in self.__datasource.spec.schema.columns:
            if x.timeIndex:
                return x.name

        raise ValueError("no time index found")

    @property
    def datatime_column_names(self):
        """
        return the list of data time column
        :return: the time series columns
        """
        return [x.name for x in self.__datasource.spec.schema.columns if x.datatype == consts.DataType_DateTime]

    @property
    def column_names(self):
        """
        return the list all the column names
        :return: the time series columns
        """
        all = [x.name for x in self.__datasource.spec.schema.columns]
        return all

    @property
    def numeric_column_names(self):
        """
        return the list of numerical column names
        :return: the time series columns
        """
        return [x.name for x in self.__datasource.spec.schema.columns if x.datatype == consts.DataType_Number]

    @property
    def categorical_column_names(self):
        """
        return the list of data time column
        :return: the time series columns
        """
        return [x.name for x in self.__datasource.spec.schema.columns if x.datatype == consts.DataType_Categorical]

    @property
    def boolean_column_names(self):
        """
        return the list of data time column
        :return: the time series columns
        """
        return [x.name for x in self.__datasource.spec.schema.columns if x.datatype == consts.DataType_Boolean]

    @property
    def datetime_format(self):
        #
        # Find the timeIndex column and return the datatime format
        #
        for x in self.__datasource.spec.schema.columns:
            if x.timeIndex:
                return x.datetimeFormat

        raise ValueError("no time index found")

    @property
    def regressors_columns(self):
        result = []
        for x in self.__datasource.spec.schema.columns:
            if x.regressor:
                result.append(x)
        return result


    #####################################################
    # Access to the data in the data source.
    #####################################################


    @property
    def y(self) :
        return self.__df[self.time_series_columns]


    @property
    def df(self) -> pd.DataFrame:
        return self.__df


    @df.setter
    def df(self, df):
        self.__df = df

    @property
    def point_forecast(self):
        return self.__y_point_forecast

    @point_forecast.setter
    def point_forecast(self,df):
        self.__y_point_forecast = df

    @property
    def interval_forecast(self):
        return self.__y_interval_forecast

    @interval_forecast.setter
    def interval_forecast(self, df):
        self.__y_interval_forecast = df

    @property
    def quantile_forecast(self):
        return self.__y_quantile_forecast

    @quantile_forecast.setter
    def quantile_forecast(self, df):
        self.__y_quantile_forecast = df

    @property
    def y_train(self):
        return self.__y_train

    @y_train.setter
    def y_train(self, y_train):
        self.__y_train = y_train

    @property
    def y_test(self):
        return self.__y_test

    @y_test.setter
    def y_test(self, y_test):
        self.__y_test = y_test


    ###################
    # Past
    ###################

    @property
    def past_interval(self):
        return self.__model.spec.forecasting.past.interval

    @property
    def past_start(self):
        return self.__model.spec.forecasting.past.start

    @property
    def past_length(self):
        return self.__model.spec.forecasting.past.length


    ###################
    # Future
    ###################
    @property
    def future_interval(self):
        return self.__model.spec.forecasting.future.interval

    @property
    def future_start(self):
        return self.__model.spec.forecasting.future.start

    @property
    def future_length(self):
        return self.__model.spec.forecasting.future.length

    @property
    def forecast_horizon(self):
        """
        Return a future horizon
        :return:
        """
        return np.arange(self.future_start,self.future_length) + 1

    ######################
    # Time series features
    ######################
    @property
    def features(self):
        """
        return the time series features.
        :return:
        """
        result = []
        for x in self.__model.spec.forecasting.features:
            result.append(x.name)
        return result

    ######################
    # forecaster pipeline
    ######################
    @property
    def pipeline_ensemble(self):
        """
        Return true if this pipeline is ensemble
        :return:
        """
        return self.__model.spec.forecasting.pipeline.ensembe

    @property
    def pipeline_imputation(self):
        """
        Return true if this pipeline is ensemble
        :return:
        """
        return self.__model.spec.forecasting.pipeline.imputation

    @property
    def pipeline_encoding(self):
        return self.__model.spec.forecasting.pipeline.encoding

    @property
    def pipeline_scaling(self):
        return self.__model.spec.forecasting.pipeline.scaling

    @property
    def pipeline_encode_date(self):
        return self.__model.spec.forecasting.pipeline.date

    @property
    def pipeline_windows(self):
        return self.__model.spec.forecasting.pipeline.windows

    @property
    def pipeline_lags(self):
        return self.__model.spec.forecasting.pipeline.lags

    @property
    def pipeline_windows_functions(self):
        return self.__model.spec.forecasting.pipeline.functions

    @property
    def pipeline_ema(self):
        return self.__model.spec.forecasting.pipeline.ema

    @property
    def pipeline_log(self):
        return self.__model.spec.forecasting.pipeline.log

    @property
    def pipeline_reduction(self):
        return self.__model.spec.forecasting.pipeline.reduction

    @property
    def pipeline_reduction_strategy(self):
        return self.__model.spec.forecasting.pipeline.strategy

    def read_csv(self,fname,keep_time=False,reindex_on_time=True):
         """read the history from a csv file"""
         df = pd.read_csv(fname,parse_dates=self.time_series_columns,squeeze=True,infer_datetime_format=True)
         df = df[self.column_names]
         # convert the types
         for x in self.numeric_column_names:
             df[x] = pd.to_numeric(df[x])
         for x in self.boolean_column_names:
             df[x] = df[x].as_type("bool")
         for x in self.categorical_column_names:
             df[x] = pd.Categorical(df[x])
         for x in self.datatime_column_names:
             df[x] = pd.to_datetime(df[x])

         values = df[self.time_column_name]
         if reindex_on_time:
             index = pd.PeriodIndex(values,freq=self.freq)
             df = df.set_index(index)
         if not keep_time:
            del df[self.time_column_name]
         self.__df = df

    def read_parque(self, fname: str):
        """read the history from a parqye file"""
        df = pd.read_parquet(fname)
        values = df[self.time_column_name]
        if reindex_on_time:
             index = pd.PeriodIndex(values,freq=self.freq)
             df = df.set_index(index)
        if not keep_time:
             del df[self.time_column_name]
        self.__df = df



    ######################################################
    # Methods based on the lecture
    ######################################################


    def seasonal_decomposition_additive(self):
        # residual - component that we cannot account for.
        # The behivor of the residual series, is different across time series.
        # T * S - multpective - level of the seasonality is bigger.

        from statsmodels.tsa.seasonal import seasonal_decompose
        decomp = seasonal_decompose(self.df,period =12)
        figure = decomp.plot()
        return figure

    def seasonal_decomposition_mulitpecative(self):
        # montly data - only period make sense if montly.
        # daily - is call.
        # in sale ,annual + seasonality.
        # tempretature - anaually.
        # test which seasonality by computing both.
        # state based model.

        #https: // www.youtube.com / watch?v = kAI67Sz92 - s
        pass

    def extract_features(self) ->Dict[str,float]:
        result = {}

        result["abs_energy"] =  abs_energy(self)

        result["absolute_maximum"] =  absolute_maximum(self)

        result["absolute_sum_of_changes"] = absolute_sum_of_changes(self)

        #result["agg_autocorrelation"] =  agg_autocorrelation(self, param)

        #result["agg_linear_trend"] =   agg_linear_trend(self, param)

        #result["approximate_entropy"] = approximate_entropy(self, m, r)

        #result["ar_coefficient"]  = ar_coefficient(self, param)

        #result["autocorrelation"] = autocorrelation(self, lag)

        result["benford_correlation"] = benford_correlation(self)

        #result["binned_entropy"] = binned_entropy(self, max_bins)

        #result["c3"] = c3(self, lag)

        #result["change_quantiles"] = change_quantiles(self, ql, qh, isabs, f_agg)

        #result["cid_ce"] = cid_ce(self, normalize)

        #result["count_above"] = count_above(self, t)

        result["count_above_mean"] = count_above_mean(self)

        #result["count_below"] = count_below(self, t)

        result["count_below_mean"] = count_below_mean(self)

        #result["cwt_coefficients"] = cwt_coefficients(self, param)

        #result["energy_ratio_by_chunks"] = energy_ratio_by_chunks(self, param)

        #result["fft_aggregated"] = fft_aggregated(self, param)

        #result["fft_coefficient"] = fft_coefficient(self, param)

        result["first_location_of_maximum"] = first_location_of_maximum(self)

        result["first_location_of_minimum"] = first_location_of_minimum(self)

        #result["fourier_entropy"] = fourier_entropy(self, bins)

        #result["friedrich_coefficients"] = friedrich_coefficients(self, param)

        result["has_duplicate"] = has_duplicate(self)

        result["has_duplicate_max"] = has_duplicate_max(self)

        result["has_duplicate_min"] = has_duplicate_min(self)

        #result["index_mass_quantile"] = index_mass_quantile(self, param)

        result["kurtosis"] = kurtosis(self)

        #result["large_standard_deviation"] = large_standard_deviation(self, r)

        result["last_location_of_maximum"] = last_location_of_maximum(self)

        result["last_location_of_minimum"] = last_location_of_minimum(self)

#        result["lempel_ziv_complexity"] = lempel_ziv_complexity(self, bins)

        result["length"] = length(self)

        #result["linear_trend"] = linear_trend(self, param)

        #result["linear_trend_timewise"] = linear_trend_timewise(self, param)

        result["longest_strike_above_mean"] = longest_strike_above_mean(self)

        result["longest_strike_below_mean"] = longest_strike_below_mean(self)

        #result["matrix_profile"] = matrix_profile(self, param)

        #result["max_langevin_fixed_point"] = max_langevin_fixed_point(self, r, m)

        result["maximum"] = maximum(self)

        result["mean"] = mean(self)

        result["mean_abs_change"] = mean_abs_change(self)

        result["mean_change"] = mean_change(self)

        #result["mean_n_absolute_max"] = mean_n_absolute_max(self, number_of_maxima)

        result["mean_second_derivative_central"] = mean_second_derivative_central(self)

        result["median"] = median(self)

        result["minimum"] = minimum(self)

        #result["number_crossing_m"] = number_crossing_m(self, m)

        #result["number_cwt_peaks"] = number_cwt_peaks(self, n)

        #result["number_peaks"] = number_peaks(self, n)

        #result["partial_autocorrelation"] = partial_autocorrelation(self, param)

        result["percentage_of_reoccurring_datapoints_to_all_datapoints"] = percentage_of_reoccurring_datapoints_to_all_datapoints(self)

        result["percentage_of_reoccurring_values_to_all_values"] = percentage_of_reoccurring_values_to_all_values(self)

        #result["permutation_entropy"] = permutation_entropy(self, tau, dimension)

        #result["quantile"] = quantile(self, q)

        #result["query_similarity_count"] = query_similarity_count(self, param)

        result["range_count"] = range_count(self, min, max)

        # result["ratio_beyond_r_sigma"] = ratio_beyond_r_sigma(self, r)

        result["ratio_value_number_to_time_series_length"] = ratio_value_number_to_time_series_length(self)

        result["root_mean_square"] = root_mean_square(self)

        result["sample_entropy"] = sample_entropy(self)

        result["skewness"] = skewness(self)

        #result["spkt_welch_density"] = spkt_welch_density(self, param)

        result["standard_deviation"] = standard_deviation(self)

        result["sum_of_reoccurring_data_points"] = sum_of_reoccurring_data_points(self)

        result["sum_of_reoccurring_values"] = sum_of_reoccurring_values(self)

        result["sum_values"] = sum_values(self)

        #result["symmetry_looking"] = symmetry_looking(self, param)

        #result["time_reversal_asymmetry_statistic"] = time_reversal_asymmetry_statistic(self, lag)

        #result["value_count"] = value_count(self, value)

        result["variance"] = variance(self)

        result["variance_larger_than_standard_deviation"] = variance_larger_than_standard_deviation(self)

        result["variation_coefficient"] = variation_coefficient(self)

        return result







def abs_energy(ts:MTimeSeries):
    return abs_energy(ts.y)


def absolute_maximum(ts:MTimeSeries):
    return absolute_maximum(ts.y.values)


def absolute_sum_of_changes(ts:MTimeSeries):
    return absolute_sum_of_changes(ts.y)


def agg_autocorrelation(ts:MTimeSeries, param):
    return agg_autocorrelation(ts.y, param)


def agg_linear_trend(ts:MTimeSeries, param):
    return agg_linear_trend(ts.y, param)


def approximate_entropy(ts:MTimeSeries, m, r):
    return approximate_entropy(ts.y, m, r)


def ar_coefficient(ts:MTimeSeries, param):
    return ar_coefficient(ts.y, param)


def autocorrelation(ts:MTimeSeries, lag):
    return autocorrelation(ts.y, lag)


def benford_correlation(ts:MTimeSeries):
    return benford_correlation(ts.y)


def binned_entropy(ts:MTimeSeries, max_bins):
    return binned_entropy(ts.y, max_bins)


def c3(ts:MTimeSeries, lag):
    return c3(ts.y, lag)


def change_quantiles(ts:MTimeSeries, ql, qh, isabs, f_agg):
    return change_quantiles(ts.y, ql, qh, isabs, f_agg)


def cid_ce(ts:MTimeSeries, normalize):
    return cid_ce(ts.y, normalize)


def count_above(ts:MTimeSeries, t):
    return count_above(ts.y, t)


def count_above_mean(ts:MTimeSeries):
    return count_above_mean(ts.y)


def count_below(ts:MTimeSeries, t):
    return count_below(ts.y, t)


def count_below_mean(ts:MTimeSeries):
    return count_below_mean(ts.y)


def cwt_coefficients(ts:MTimeSeries, param):
    return cwt_coefficients(ts.y,param)


def energy_ratio_by_chunks(ts:MTimeSeries, param):
    return energy_ratio_by_chunks(ts.y, param)


def fft_aggregated(ts:MTimeSeries, param):
    return fft_aggregated(ts.y, param)


def fft_coefficient(ts:MTimeSeries, param):
    return fft_coefficient(ts.y, param)


def first_location_of_maximum(ts:MTimeSeries):
    return first_location_of_maximum(ts.y)


def first_location_of_minimum(ts:MTimeSeries):
    return first_location_of_minimum(ts.y)


def fourier_entropy(ts:MTimeSeries, bins):
    return fourier_entropy(ts.y,bins)


def friedrich_coefficients(ts:MTimeSeries, param):
    return friedrich_coefficients(ts.y, param)


def has_duplicate(ts:MTimeSeries):
    return has_duplicate(ts.y)


def has_duplicate_max(ts:MTimeSeries):
    return has_duplicate_max(ts.y)


def has_duplicate_min(ts:MTimeSeries):
    return has_duplicate_min(ts.y)


def index_mass_quantile(ts:MTimeSeries, param):
    return index_mass_quantile(ts.y, param)


def kurtosis(ts:MTimeSeries):
    return kurtosis(ts.y)


def large_standard_deviation(ts:MTimeSeries, r):
    return large_standard_deviation(ts.y, r)


def last_location_of_maximum(ts:MTimeSeries):
    return last_location_of_maximum(ts.y)


def last_location_of_minimum(ts:MTimeSeries):
    return last_location_of_minimum(ts.y)


def lempel_ziv_complexity(ts:MTimeSeries, bins):
    return lempel_ziv_complexity(ts.y, bins)


def length(ts:MTimeSeries):
    return length(ts.y)


def linear_trend(ts:MTimeSeries, param):
    return linear_trend(ts.y, param)


def linear_trend_timewise(ts:MTimeSeries, param):
    return linear_trend_timewise(ts.y, param)


def longest_strike_above_mean(ts:MTimeSeries):
    return longest_strike_above_mean(ts.y)


def longest_strike_below_mean(ts:MTimeSeries):
    return longest_strike_below_mean(ts.y)


def matrix_profile(ts:MTimeSeries, param):
    return matrix_profile(ts.y, param)


def max_langevin_fixed_point(ts:MTimeSeries, r, m):
    return max_langevin_fixed_point(ts.y, r, m)


def maximum(ts:MTimeSeries):
    return maximum(ts.y)


def mean(ts:MTimeSeries):
    return mean(ts.y)


def mean_abs_change(ts:MTimeSeries):
    return mean_abs_change(ts.y)


def mean_change(ts:MTimeSeries):
    return mean_change(ts.y)


def mean_n_absolute_max(ts:MTimeSeries, number_of_maxima):
    return mean_n_absolute_max(ts.y, number_of_maxima)


def mean_second_derivative_central(ts:MTimeSeries):
    return mean_second_derivative_central(ts.y)


def median(ts:MTimeSeries):
    return median(ts.y)


def minimum(ts:MTimeSeries):
    return minimum(ts.y)


def number_crossing_m(ts:MTimeSeries, m):
    return number_crossing_m(ts.y, m)


def number_cwt_peaks(ts:MTimeSeries, n):
    return number_cwt_peaks(ts.y, n)


def number_peaks(ts:MTimeSeries, n):
    return number_peaks(ts.y, n)


def partial_autocorrelation(ts:MTimeSeries, param):
    return partial_autocorrelation(ts.y, param)


def percentage_of_reoccurring_datapoints_to_all_datapoints(ts:MTimeSeries):
    return percentage_of_reoccurring_datapoints_to_all_datapoints(ts.y)


def percentage_of_reoccurring_values_to_all_values(ts:MTimeSeries):
    return percentage_of_reoccurring_values_to_all_values(ts.y)


def permutation_entropy(ts:MTimeSeries, tau, dimension):
    return permutation_entropy(ts.y, tau, dimension)


def quantile(ts:MTimeSeries, q):
    return quantile(ts.y, q)


def query_similarity_count(ts:MTimeSeries, param):
    return query_similarity_count(ts.y, param)


def range_count(ts:MTimeSeries, min, max):
    return range_count(ts.y, min, max)


def ratio_beyond_r_sigma(ts:MTimeSeries, r):
    return ratio_beyond_r_sigma(ts.y, r)


def ratio_value_number_to_time_series_length(ts:MTimeSeries):
    return ratio_value_number_to_time_series_length(ts.y)


def root_mean_square(ts:MTimeSeries):
    return root_mean_square(ts.y)


def sample_entropy(ts:MTimeSeries):
    return sample_entropy(ts.y)


def skewness(ts:MTimeSeries):
    return skewness(ts.y)


def spkt_welch_density(ts:MTimeSeries, param):
    return spkt_welch_density(ts.y,param)


def standard_deviation(ts:MTimeSeries):
    return standard_deviation(ts.y)


def sum_of_reoccurring_data_points(ts:MTimeSeries):
    return sum_of_reoccurring_data_points(ts.y)


def sum_of_reoccurring_values(ts:MTimeSeries):
    return sum_of_reoccurring_values(ts.y)


def sum_values(ts:MTimeSeries):
    return sum_values(ts.y)


def symmetry_looking(ts:MTimeSeries, param):
    return symmetry_looking(ts.y, param)


def time_reversal_asymmetry_statistic(ts:MTimeSeries, lag):
    return time_reversal_asymmetry_statistic(ts.y, lag)


def value_count(ts:MTimeSeries, value):
    return value_count(ts.y, value)


def variance(ts:MTimeSeries):
    return variance(ts.y)


def variance_larger_than_standard_deviation(ts:MTimeSeries):
    return variance_larger_than_standard_deviation(ts.y)


def variation_coefficient(ts:MTimeSeries):
    return variation_coefficient(ts.y)


def adf_test(ts:MTimeSeries) -> Tuple[float, float]:
    """run adf test,
    :return Tuple of adf stat and p value
    """
    result,pvalue = adfuller(ts.y, autolag="AIC")
    return result, pvalue

def kpss_test(ts:MTimeSeries):
    """
    Run kpss test.
    :return: A tuple of kpss stat and p value
    """
    result = kpss(ts.y, regression="c")
    return result

def calc_validation_metric(ts:MTimeSeries, metric: str, other: pd.Series) -> float:
    if metric == consts.Metric_MSE:
        return mse(ts.y_test, other)
    if metric == consts.Metric_RMSE:
        return rmse(ts.y, other)
    if metric == consts.Metric_MAE:
        return mae(ts.y, other)
    if metric == consts.Metric_MAPE:
        return mape(ts.y, other)


def smape(y_actual: pd.Series, y_predicted: pd.Series) -> float:
        y_true, y_pred = np.array(y_actual), np.array(y_predicted)
        return np.mean(np.abs((y_true - y_pred) / y_true)) * 100

def mse(y_actual: pd.Series, y_predicted: pd.Series) -> float:
        return sklearn.metrics.mean_squared_error(y_actual, y_predicted)

def rmse(y_actual: pd.Series, y_predicted: pd.Series) -> float:
        return np.sqrt(sklearn.metrics.mean_squared_error(y_actual, y_predicted))

def mae(y_actual: pd.Series, y_predicted: pd.Series) -> float:
        return sklearn.metrics.mean_absolute_error(y_actual, y_predicted)

def mape( y_actual: pd.Series, y_predicted: pd.Series) -> float:
        actual, pred = np.array(y_actual), np.array(y_predicted)
        return np.mean(np.abs((actual - pred) / actual)) * 100

def wape(y_actual: pd.Series, y_predicted: pd.Series) -> float:
        return (y_actual - y_predicted).abs().sum() / y_actual.sum()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from k8s.io.apimachinery.pkg.runtime import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime.schema import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x12$k8s.io.apimachinery.pkg.apis.meta.v1\x1a/k8s.io/apimachinery/pkg/runtime/generated.proto\x1a\x36k8s.io/apimachinery/pkg/runtime/schema/generated.proto\"\xa9\x02\n\x08\x41PIGroup\x12\x0c\n\x04name\x18\x01 \x01(\t\x12P\n\x08versions\x18\x02 \x03(\x0b\x32>.k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionForDiscovery\x12X\n\x10preferredVersion\x18\x03 \x01(\x0b\x32>.k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionForDiscovery\x12\x63\n\x1aserverAddressByClientCIDRs\x18\x04 \x03(\x0b\x32?.k8s.io.apimachinery.pkg.apis.meta.v1.ServerAddressByClientCIDR\"N\n\x0c\x41PIGroupList\x12>\n\x06groups\x18\x01 \x03(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.APIGroup\"\xf3\x01\n\x0b\x41PIResource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0csingularName\x18\x06 \x01(\t\x12\x12\n\nnamespaced\x18\x02 \x01(\x08\x12\r\n\x05group\x18\x08 \x01(\t\x12\x0f\n\x07version\x18\t \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12:\n\x05verbs\x18\x04 \x01(\x0b\x32+.k8s.io.apimachinery.pkg.apis.meta.v1.Verbs\x12\x12\n\nshortNames\x18\x05 \x03(\t\x12\x12\n\ncategories\x18\x07 \x03(\t\x12\x1a\n\x12storageVersionHash\x18\n \x01(\t\"m\n\x0f\x41PIResourceList\x12\x14\n\x0cgroupVersion\x18\x01 \x01(\t\x12\x44\n\tresources\x18\x02 \x03(\x0b\x32\x31.k8s.io.apimachinery.pkg.apis.meta.v1.APIResource\"\x84\x01\n\x0b\x41PIVersions\x12\x10\n\x08versions\x18\x01 \x03(\t\x12\x63\n\x1aserverAddressByClientCIDRs\x18\x02 \x03(\x0b\x32?.k8s.io.apimachinery.pkg.apis.meta.v1.ServerAddressByClientCIDR\"C\n\x0c\x41pplyOptions\x12\x0e\n\x06\x64ryRun\x18\x01 \x03(\t\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\x12\x14\n\x0c\x66ieldManager\x18\x03 \x01(\t\"\xae\x01\n\tCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x03 \x01(\x03\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"N\n\rCreateOptions\x12\x0e\n\x06\x64ryRun\x18\x01 \x03(\t\x12\x14\n\x0c\x66ieldManager\x18\x03 \x01(\t\x12\x17\n\x0f\x66ieldValidation\x18\x04 \x01(\t\"\xbc\x01\n\rDeleteOptions\x12\x1a\n\x12gracePeriodSeconds\x18\x01 \x01(\x03\x12J\n\rpreconditions\x18\x02 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.Preconditions\x12\x18\n\x10orphanDependents\x18\x03 \x01(\x08\x12\x19\n\x11propagationPolicy\x18\x04 \x01(\t\x12\x0e\n\x06\x64ryRun\x18\x05 \x03(\t\"\x1c\n\x08\x44uration\x12\x10\n\x08\x64uration\x18\x01 \x01(\x03\"\x17\n\x08\x46ieldsV1\x12\x0b\n\x03Raw\x18\x01 \x01(\x0c\"%\n\nGetOptions\x12\x17\n\x0fresourceVersion\x18\x01 \x01(\t\"(\n\tGroupKind\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\"0\n\rGroupResource\x12\r\n\x05group\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\".\n\x0cGroupVersion\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"A\n\x18GroupVersionForDiscovery\x12\x14\n\x0cgroupVersion\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"@\n\x10GroupVersionKind\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\"H\n\x14GroupVersionResource\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x10\n\x08resource\x18\x03 \x01(\t\"\xf8\x01\n\rLabelSelector\x12Y\n\x0bmatchLabels\x18\x01 \x03(\x0b\x32\x44.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector.MatchLabelsEntry\x12X\n\x10matchExpressions\x18\x02 \x03(\x0b\x32>.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelectorRequirement\x1a\x32\n\x10MatchLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x18LabelSelectorRequirement\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\x86\x01\n\x04List\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12<\n\x05items\x18\x02 \x03(\x0b\x32-.k8s.io.apimachinery.pkg.runtime.RawExtension\"c\n\x08ListMeta\x12\x10\n\x08selfLink\x18\x01 \x01(\t\x12\x17\n\x0fresourceVersion\x18\x02 \x01(\t\x12\x10\n\x08\x63ontinue\x18\x03 \x01(\t\x12\x1a\n\x12remainingItemCount\x18\x04 \x01(\x03\"\xd7\x01\n\x0bListOptions\x12\x15\n\rlabelSelector\x18\x01 \x01(\t\x12\x15\n\rfieldSelector\x18\x02 \x01(\t\x12\r\n\x05watch\x18\x03 \x01(\x08\x12\x1b\n\x13\x61llowWatchBookmarks\x18\t \x01(\x08\x12\x17\n\x0fresourceVersion\x18\x04 \x01(\t\x12\x1c\n\x14resourceVersionMatch\x18\n \x01(\t\x12\x16\n\x0etimeoutSeconds\x18\x05 \x01(\x03\x12\r\n\x05limit\x18\x07 \x01(\x03\x12\x10\n\x08\x63ontinue\x18\x08 \x01(\t\"\xf1\x01\n\x12ManagedFieldsEntry\x12\x0f\n\x07manager\x18\x01 \x01(\t\x12\x11\n\toperation\x18\x02 \x01(\t\x12\x12\n\napiVersion\x18\x03 \x01(\t\x12\x38\n\x04time\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x12\n\nfieldsType\x18\x06 \x01(\t\x12@\n\x08\x66ieldsV1\x18\x07 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.FieldsV1\x12\x13\n\x0bsubresource\x18\x08 \x01(\t\"+\n\tMicroTime\x12\x0f\n\x07seconds\x18\x01 \x01(\x03\x12\r\n\x05nanos\x18\x02 \x01(\x05\"\x93\x06\n\nObjectMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cgenerateName\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x10\n\x08selfLink\x18\x04 \x01(\t\x12\x0b\n\x03uid\x18\x05 \x01(\t\x12\x17\n\x0fresourceVersion\x18\x06 \x01(\t\x12\x12\n\ngeneration\x18\x07 \x01(\x03\x12\x45\n\x11\x63reationTimestamp\x18\x08 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x45\n\x11\x64\x65letionTimestamp\x18\t \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\"\n\x1a\x64\x65letionGracePeriodSeconds\x18\n \x01(\x03\x12L\n\x06labels\x18\x0b \x03(\x0b\x32<.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.LabelsEntry\x12V\n\x0b\x61nnotations\x18\x0c \x03(\x0b\x32\x41.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.AnnotationsEntry\x12M\n\x0fownerReferences\x18\r \x03(\x0b\x32\x34.k8s.io.apimachinery.pkg.apis.meta.v1.OwnerReference\x12\x12\n\nfinalizers\x18\x0e \x03(\t\x12\x13\n\x0b\x63lusterName\x18\x0f \x01(\t\x12O\n\rmanagedFields\x18\x11 \x03(\x0b\x32\x38.k8s.io.apimachinery.pkg.apis.meta.v1.ManagedFieldsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"}\n\x0eOwnerReference\x12\x12\n\napiVersion\x18\x05 \x01(\t\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\t\x12\x12\n\ncontroller\x18\x06 \x01(\x08\x12\x1a\n\x12\x62lockOwnerDeletion\x18\x07 \x01(\x08\"[\n\x15PartialObjectMetadata\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\"\xa9\x01\n\x19PartialObjectMetadataList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12J\n\x05items\x18\x02 \x03(\x0b\x32;.k8s.io.apimachinery.pkg.apis.meta.v1.PartialObjectMetadata\"\x07\n\x05Patch\"\\\n\x0cPatchOptions\x12\x0e\n\x06\x64ryRun\x18\x01 \x03(\t\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\x12\x14\n\x0c\x66ieldManager\x18\x03 \x01(\t\x12\x17\n\x0f\x66ieldValidation\x18\x04 \x01(\t\"5\n\rPreconditions\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x17\n\x0fresourceVersion\x18\x02 \x01(\t\"\x1a\n\tRootPaths\x12\r\n\x05paths\x18\x01 \x03(\t\"F\n\x19ServerAddressByClientCIDR\x12\x12\n\nclientCIDR\x18\x01 \x01(\t\x12\x15\n\rserverAddress\x18\x02 \x01(\t\"\xcf\x01\n\x06Status\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x44\n\x07\x64\x65tails\x18\x05 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.StatusDetails\x12\x0c\n\x04\x63ode\x18\x06 \x01(\x05\"=\n\x0bStatusCause\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x66ield\x18\x03 \x01(\t\"\xa5\x01\n\rStatusDetails\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05group\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x06 \x01(\t\x12\x41\n\x06\x63\x61uses\x18\x04 \x03(\x0b\x32\x31.k8s.io.apimachinery.pkg.apis.meta.v1.StatusCause\x12\x19\n\x11retryAfterSeconds\x18\x05 \x01(\x05\"%\n\x0cTableOptions\x12\x15\n\rincludeObject\x18\x01 \x01(\t\"&\n\x04Time\x12\x0f\n\x07seconds\x18\x01 \x01(\x03\x12\r\n\x05nanos\x18\x02 \x01(\x05\"+\n\tTimestamp\x12\x0f\n\x07seconds\x18\x01 \x01(\x03\x12\r\n\x05nanos\x18\x02 \x01(\x05\",\n\x08TypeMeta\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x12\n\napiVersion\x18\x02 \x01(\t\"N\n\rUpdateOptions\x12\x0e\n\x06\x64ryRun\x18\x01 \x03(\t\x12\x14\n\x0c\x66ieldManager\x18\x02 \x01(\t\x12\x17\n\x0f\x66ieldValidation\x18\x03 \x01(\t\"\x16\n\x05Verbs\x12\r\n\x05items\x18\x01 \x03(\t\"Y\n\nWatchEvent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12=\n\x06object\x18\x02 \x01(\x0b\x32-.k8s.io.apimachinery.pkg.runtime.RawExtensionB&Z$k8s.io/apimachinery/pkg/apis/meta/v1')



_APIGROUP = DESCRIPTOR.message_types_by_name['APIGroup']
_APIGROUPLIST = DESCRIPTOR.message_types_by_name['APIGroupList']
_APIRESOURCE = DESCRIPTOR.message_types_by_name['APIResource']
_APIRESOURCELIST = DESCRIPTOR.message_types_by_name['APIResourceList']
_APIVERSIONS = DESCRIPTOR.message_types_by_name['APIVersions']
_APPLYOPTIONS = DESCRIPTOR.message_types_by_name['ApplyOptions']
_CONDITION = DESCRIPTOR.message_types_by_name['Condition']
_CREATEOPTIONS = DESCRIPTOR.message_types_by_name['CreateOptions']
_DELETEOPTIONS = DESCRIPTOR.message_types_by_name['DeleteOptions']
_DURATION = DESCRIPTOR.message_types_by_name['Duration']
_FIELDSV1 = DESCRIPTOR.message_types_by_name['FieldsV1']
_GETOPTIONS = DESCRIPTOR.message_types_by_name['GetOptions']
_GROUPKIND = DESCRIPTOR.message_types_by_name['GroupKind']
_GROUPRESOURCE = DESCRIPTOR.message_types_by_name['GroupResource']
_GROUPVERSION = DESCRIPTOR.message_types_by_name['GroupVersion']
_GROUPVERSIONFORDISCOVERY = DESCRIPTOR.message_types_by_name['GroupVersionForDiscovery']
_GROUPVERSIONKIND = DESCRIPTOR.message_types_by_name['GroupVersionKind']
_GROUPVERSIONRESOURCE = DESCRIPTOR.message_types_by_name['GroupVersionResource']
_LABELSELECTOR = DESCRIPTOR.message_types_by_name['LabelSelector']
_LABELSELECTOR_MATCHLABELSENTRY = _LABELSELECTOR.nested_types_by_name['MatchLabelsEntry']
_LABELSELECTORREQUIREMENT = DESCRIPTOR.message_types_by_name['LabelSelectorRequirement']
_LIST = DESCRIPTOR.message_types_by_name['List']
_LISTMETA = DESCRIPTOR.message_types_by_name['ListMeta']
_LISTOPTIONS = DESCRIPTOR.message_types_by_name['ListOptions']
_MANAGEDFIELDSENTRY = DESCRIPTOR.message_types_by_name['ManagedFieldsEntry']
_MICROTIME = DESCRIPTOR.message_types_by_name['MicroTime']
_OBJECTMETA = DESCRIPTOR.message_types_by_name['ObjectMeta']
_OBJECTMETA_LABELSENTRY = _OBJECTMETA.nested_types_by_name['LabelsEntry']
_OBJECTMETA_ANNOTATIONSENTRY = _OBJECTMETA.nested_types_by_name['AnnotationsEntry']
_OWNERREFERENCE = DESCRIPTOR.message_types_by_name['OwnerReference']
_PARTIALOBJECTMETADATA = DESCRIPTOR.message_types_by_name['PartialObjectMetadata']
_PARTIALOBJECTMETADATALIST = DESCRIPTOR.message_types_by_name['PartialObjectMetadataList']
_PATCH = DESCRIPTOR.message_types_by_name['Patch']
_PATCHOPTIONS = DESCRIPTOR.message_types_by_name['PatchOptions']
_PRECONDITIONS = DESCRIPTOR.message_types_by_name['Preconditions']
_ROOTPATHS = DESCRIPTOR.message_types_by_name['RootPaths']
_SERVERADDRESSBYCLIENTCIDR = DESCRIPTOR.message_types_by_name['ServerAddressByClientCIDR']
_STATUS = DESCRIPTOR.message_types_by_name['Status']
_STATUSCAUSE = DESCRIPTOR.message_types_by_name['StatusCause']
_STATUSDETAILS = DESCRIPTOR.message_types_by_name['StatusDetails']
_TABLEOPTIONS = DESCRIPTOR.message_types_by_name['TableOptions']
_TIME = DESCRIPTOR.message_types_by_name['Time']
_TIMESTAMP = DESCRIPTOR.message_types_by_name['Timestamp']
_TYPEMETA = DESCRIPTOR.message_types_by_name['TypeMeta']
_UPDATEOPTIONS = DESCRIPTOR.message_types_by_name['UpdateOptions']
_VERBS = DESCRIPTOR.message_types_by_name['Verbs']
_WATCHEVENT = DESCRIPTOR.message_types_by_name['WatchEvent']
APIGroup = _reflection.GeneratedProtocolMessageType('APIGroup', (_message.Message,), {
  'DESCRIPTOR' : _APIGROUP,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.APIGroup)
  })
_sym_db.RegisterMessage(APIGroup)

APIGroupList = _reflection.GeneratedProtocolMessageType('APIGroupList', (_message.Message,), {
  'DESCRIPTOR' : _APIGROUPLIST,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.APIGroupList)
  })
_sym_db.RegisterMessage(APIGroupList)

APIResource = _reflection.GeneratedProtocolMessageType('APIResource', (_message.Message,), {
  'DESCRIPTOR' : _APIRESOURCE,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.APIResource)
  })
_sym_db.RegisterMessage(APIResource)

APIResourceList = _reflection.GeneratedProtocolMessageType('APIResourceList', (_message.Message,), {
  'DESCRIPTOR' : _APIRESOURCELIST,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.APIResourceList)
  })
_sym_db.RegisterMessage(APIResourceList)

APIVersions = _reflection.GeneratedProtocolMessageType('APIVersions', (_message.Message,), {
  'DESCRIPTOR' : _APIVERSIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.APIVersions)
  })
_sym_db.RegisterMessage(APIVersions)

ApplyOptions = _reflection.GeneratedProtocolMessageType('ApplyOptions', (_message.Message,), {
  'DESCRIPTOR' : _APPLYOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ApplyOptions)
  })
_sym_db.RegisterMessage(ApplyOptions)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Condition)
  })
_sym_db.RegisterMessage(Condition)

CreateOptions = _reflection.GeneratedProtocolMessageType('CreateOptions', (_message.Message,), {
  'DESCRIPTOR' : _CREATEOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.CreateOptions)
  })
_sym_db.RegisterMessage(CreateOptions)

DeleteOptions = _reflection.GeneratedProtocolMessageType('DeleteOptions', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.DeleteOptions)
  })
_sym_db.RegisterMessage(DeleteOptions)

Duration = _reflection.GeneratedProtocolMessageType('Duration', (_message.Message,), {
  'DESCRIPTOR' : _DURATION,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Duration)
  })
_sym_db.RegisterMessage(Duration)

FieldsV1 = _reflection.GeneratedProtocolMessageType('FieldsV1', (_message.Message,), {
  'DESCRIPTOR' : _FIELDSV1,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.FieldsV1)
  })
_sym_db.RegisterMessage(FieldsV1)

GetOptions = _reflection.GeneratedProtocolMessageType('GetOptions', (_message.Message,), {
  'DESCRIPTOR' : _GETOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.GetOptions)
  })
_sym_db.RegisterMessage(GetOptions)

GroupKind = _reflection.GeneratedProtocolMessageType('GroupKind', (_message.Message,), {
  'DESCRIPTOR' : _GROUPKIND,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.GroupKind)
  })
_sym_db.RegisterMessage(GroupKind)

GroupResource = _reflection.GeneratedProtocolMessageType('GroupResource', (_message.Message,), {
  'DESCRIPTOR' : _GROUPRESOURCE,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.GroupResource)
  })
_sym_db.RegisterMessage(GroupResource)

GroupVersion = _reflection.GeneratedProtocolMessageType('GroupVersion', (_message.Message,), {
  'DESCRIPTOR' : _GROUPVERSION,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersion)
  })
_sym_db.RegisterMessage(GroupVersion)

GroupVersionForDiscovery = _reflection.GeneratedProtocolMessageType('GroupVersionForDiscovery', (_message.Message,), {
  'DESCRIPTOR' : _GROUPVERSIONFORDISCOVERY,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionForDiscovery)
  })
_sym_db.RegisterMessage(GroupVersionForDiscovery)

GroupVersionKind = _reflection.GeneratedProtocolMessageType('GroupVersionKind', (_message.Message,), {
  'DESCRIPTOR' : _GROUPVERSIONKIND,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionKind)
  })
_sym_db.RegisterMessage(GroupVersionKind)

GroupVersionResource = _reflection.GeneratedProtocolMessageType('GroupVersionResource', (_message.Message,), {
  'DESCRIPTOR' : _GROUPVERSIONRESOURCE,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionResource)
  })
_sym_db.RegisterMessage(GroupVersionResource)

LabelSelector = _reflection.GeneratedProtocolMessageType('LabelSelector', (_message.Message,), {

  'MatchLabelsEntry' : _reflection.GeneratedProtocolMessageType('MatchLabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LABELSELECTOR_MATCHLABELSENTRY,
    '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector.MatchLabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LABELSELECTOR,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector)
  })
_sym_db.RegisterMessage(LabelSelector)
_sym_db.RegisterMessage(LabelSelector.MatchLabelsEntry)

LabelSelectorRequirement = _reflection.GeneratedProtocolMessageType('LabelSelectorRequirement', (_message.Message,), {
  'DESCRIPTOR' : _LABELSELECTORREQUIREMENT,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelectorRequirement)
  })
_sym_db.RegisterMessage(LabelSelectorRequirement)

List = _reflection.GeneratedProtocolMessageType('List', (_message.Message,), {
  'DESCRIPTOR' : _LIST,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.List)
  })
_sym_db.RegisterMessage(List)

ListMeta = _reflection.GeneratedProtocolMessageType('ListMeta', (_message.Message,), {
  'DESCRIPTOR' : _LISTMETA,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta)
  })
_sym_db.RegisterMessage(ListMeta)

ListOptions = _reflection.GeneratedProtocolMessageType('ListOptions', (_message.Message,), {
  'DESCRIPTOR' : _LISTOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ListOptions)
  })
_sym_db.RegisterMessage(ListOptions)

ManagedFieldsEntry = _reflection.GeneratedProtocolMessageType('ManagedFieldsEntry', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDFIELDSENTRY,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ManagedFieldsEntry)
  })
_sym_db.RegisterMessage(ManagedFieldsEntry)

MicroTime = _reflection.GeneratedProtocolMessageType('MicroTime', (_message.Message,), {
  'DESCRIPTOR' : _MICROTIME,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.MicroTime)
  })
_sym_db.RegisterMessage(MicroTime)

ObjectMeta = _reflection.GeneratedProtocolMessageType('ObjectMeta', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _OBJECTMETA_LABELSENTRY,
    '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.LabelsEntry)
    })
  ,

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _OBJECTMETA_ANNOTATIONSENTRY,
    '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _OBJECTMETA,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta)
  })
_sym_db.RegisterMessage(ObjectMeta)
_sym_db.RegisterMessage(ObjectMeta.LabelsEntry)
_sym_db.RegisterMessage(ObjectMeta.AnnotationsEntry)

OwnerReference = _reflection.GeneratedProtocolMessageType('OwnerReference', (_message.Message,), {
  'DESCRIPTOR' : _OWNERREFERENCE,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.OwnerReference)
  })
_sym_db.RegisterMessage(OwnerReference)

PartialObjectMetadata = _reflection.GeneratedProtocolMessageType('PartialObjectMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PARTIALOBJECTMETADATA,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.PartialObjectMetadata)
  })
_sym_db.RegisterMessage(PartialObjectMetadata)

PartialObjectMetadataList = _reflection.GeneratedProtocolMessageType('PartialObjectMetadataList', (_message.Message,), {
  'DESCRIPTOR' : _PARTIALOBJECTMETADATALIST,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.PartialObjectMetadataList)
  })
_sym_db.RegisterMessage(PartialObjectMetadataList)

Patch = _reflection.GeneratedProtocolMessageType('Patch', (_message.Message,), {
  'DESCRIPTOR' : _PATCH,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Patch)
  })
_sym_db.RegisterMessage(Patch)

PatchOptions = _reflection.GeneratedProtocolMessageType('PatchOptions', (_message.Message,), {
  'DESCRIPTOR' : _PATCHOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.PatchOptions)
  })
_sym_db.RegisterMessage(PatchOptions)

Preconditions = _reflection.GeneratedProtocolMessageType('Preconditions', (_message.Message,), {
  'DESCRIPTOR' : _PRECONDITIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Preconditions)
  })
_sym_db.RegisterMessage(Preconditions)

RootPaths = _reflection.GeneratedProtocolMessageType('RootPaths', (_message.Message,), {
  'DESCRIPTOR' : _ROOTPATHS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.RootPaths)
  })
_sym_db.RegisterMessage(RootPaths)

ServerAddressByClientCIDR = _reflection.GeneratedProtocolMessageType('ServerAddressByClientCIDR', (_message.Message,), {
  'DESCRIPTOR' : _SERVERADDRESSBYCLIENTCIDR,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ServerAddressByClientCIDR)
  })
_sym_db.RegisterMessage(ServerAddressByClientCIDR)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {
  'DESCRIPTOR' : _STATUS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Status)
  })
_sym_db.RegisterMessage(Status)

StatusCause = _reflection.GeneratedProtocolMessageType('StatusCause', (_message.Message,), {
  'DESCRIPTOR' : _STATUSCAUSE,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.StatusCause)
  })
_sym_db.RegisterMessage(StatusCause)

StatusDetails = _reflection.GeneratedProtocolMessageType('StatusDetails', (_message.Message,), {
  'DESCRIPTOR' : _STATUSDETAILS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.StatusDetails)
  })
_sym_db.RegisterMessage(StatusDetails)

TableOptions = _reflection.GeneratedProtocolMessageType('TableOptions', (_message.Message,), {
  'DESCRIPTOR' : _TABLEOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.TableOptions)
  })
_sym_db.RegisterMessage(TableOptions)

Time = _reflection.GeneratedProtocolMessageType('Time', (_message.Message,), {
  'DESCRIPTOR' : _TIME,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Time)
  })
_sym_db.RegisterMessage(Time)

Timestamp = _reflection.GeneratedProtocolMessageType('Timestamp', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMP,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Timestamp)
  })
_sym_db.RegisterMessage(Timestamp)

TypeMeta = _reflection.GeneratedProtocolMessageType('TypeMeta', (_message.Message,), {
  'DESCRIPTOR' : _TYPEMETA,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.TypeMeta)
  })
_sym_db.RegisterMessage(TypeMeta)

UpdateOptions = _reflection.GeneratedProtocolMessageType('UpdateOptions', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.UpdateOptions)
  })
_sym_db.RegisterMessage(UpdateOptions)

Verbs = _reflection.GeneratedProtocolMessageType('Verbs', (_message.Message,), {
  'DESCRIPTOR' : _VERBS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Verbs)
  })
_sym_db.RegisterMessage(Verbs)

WatchEvent = _reflection.GeneratedProtocolMessageType('WatchEvent', (_message.Message,), {
  'DESCRIPTOR' : _WATCHEVENT,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.WatchEvent)
  })
_sym_db.RegisterMessage(WatchEvent)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$k8s.io/apimachinery/pkg/apis/meta/v1'
  _LABELSELECTOR_MATCHLABELSENTRY._options = None
  _LABELSELECTOR_MATCHLABELSENTRY._serialized_options = b'8\001'
  _OBJECTMETA_LABELSENTRY._options = None
  _OBJECTMETA_LABELSENTRY._serialized_options = b'8\001'
  _OBJECTMETA_ANNOTATIONSENTRY._options = None
  _OBJECTMETA_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _APIGROUP._serialized_start=200
  _APIGROUP._serialized_end=497
  _APIGROUPLIST._serialized_start=499
  _APIGROUPLIST._serialized_end=577
  _APIRESOURCE._serialized_start=580
  _APIRESOURCE._serialized_end=823
  _APIRESOURCELIST._serialized_start=825
  _APIRESOURCELIST._serialized_end=934
  _APIVERSIONS._serialized_start=937
  _APIVERSIONS._serialized_end=1069
  _APPLYOPTIONS._serialized_start=1071
  _APPLYOPTIONS._serialized_end=1138
  _CONDITION._serialized_start=1141
  _CONDITION._serialized_end=1315
  _CREATEOPTIONS._serialized_start=1317
  _CREATEOPTIONS._serialized_end=1395
  _DELETEOPTIONS._serialized_start=1398
  _DELETEOPTIONS._serialized_end=1586
  _DURATION._serialized_start=1588
  _DURATION._serialized_end=1616
  _FIELDSV1._serialized_start=1618
  _FIELDSV1._serialized_end=1641
  _GETOPTIONS._serialized_start=1643
  _GETOPTIONS._serialized_end=1680
  _GROUPKIND._serialized_start=1682
  _GROUPKIND._serialized_end=1722
  _GROUPRESOURCE._serialized_start=1724
  _GROUPRESOURCE._serialized_end=1772
  _GROUPVERSION._serialized_start=1774
  _GROUPVERSION._serialized_end=1820
  _GROUPVERSIONFORDISCOVERY._serialized_start=1822
  _GROUPVERSIONFORDISCOVERY._serialized_end=1887
  _GROUPVERSIONKIND._serialized_start=1889
  _GROUPVERSIONKIND._serialized_end=1953
  _GROUPVERSIONRESOURCE._serialized_start=1955
  _GROUPVERSIONRESOURCE._serialized_end=2027
  _LABELSELECTOR._serialized_start=2030
  _LABELSELECTOR._serialized_end=2278
  _LABELSELECTOR_MATCHLABELSENTRY._serialized_start=2228
  _LABELSELECTOR_MATCHLABELSENTRY._serialized_end=2278
  _LABELSELECTORREQUIREMENT._serialized_start=2280
  _LABELSELECTORREQUIREMENT._serialized_end=2353
  _LIST._serialized_start=2356
  _LIST._serialized_end=2490
  _LISTMETA._serialized_start=2492
  _LISTMETA._serialized_end=2591
  _LISTOPTIONS._serialized_start=2594
  _LISTOPTIONS._serialized_end=2809
  _MANAGEDFIELDSENTRY._serialized_start=2812
  _MANAGEDFIELDSENTRY._serialized_end=3053
  _MICROTIME._serialized_start=3055
  _MICROTIME._serialized_end=3098
  _OBJECTMETA._serialized_start=3101
  _OBJECTMETA._serialized_end=3888
  _OBJECTMETA_LABELSENTRY._serialized_start=3791
  _OBJECTMETA_LABELSENTRY._serialized_end=3836
  _OBJECTMETA_ANNOTATIONSENTRY._serialized_start=3838
  _OBJECTMETA_ANNOTATIONSENTRY._serialized_end=3888
  _OWNERREFERENCE._serialized_start=3890
  _OWNERREFERENCE._serialized_end=4015
  _PARTIALOBJECTMETADATA._serialized_start=4017
  _PARTIALOBJECTMETADATA._serialized_end=4108
  _PARTIALOBJECTMETADATALIST._serialized_start=4111
  _PARTIALOBJECTMETADATALIST._serialized_end=4280
  _PATCH._serialized_start=4282
  _PATCH._serialized_end=4289
  _PATCHOPTIONS._serialized_start=4291
  _PATCHOPTIONS._serialized_end=4383
  _PRECONDITIONS._serialized_start=4385
  _PRECONDITIONS._serialized_end=4438
  _ROOTPATHS._serialized_start=4440
  _ROOTPATHS._serialized_end=4466
  _SERVERADDRESSBYCLIENTCIDR._serialized_start=4468
  _SERVERADDRESSBYCLIENTCIDR._serialized_end=4538
  _STATUS._serialized_start=4541
  _STATUS._serialized_end=4748
  _STATUSCAUSE._serialized_start=4750
  _STATUSCAUSE._serialized_end=4811
  _STATUSDETAILS._serialized_start=4814
  _STATUSDETAILS._serialized_end=4979
  _TABLEOPTIONS._serialized_start=4981
  _TABLEOPTIONS._serialized_end=5018
  _TIME._serialized_start=5020
  _TIME._serialized_end=5058
  _TIMESTAMP._serialized_start=5060
  _TIMESTAMP._serialized_end=5103
  _TYPEMETA._serialized_start=5105
  _TYPEMETA._serialized_end=5149
  _UPDATEOPTIONS._serialized_start=5151
  _UPDATEOPTIONS._serialized_end=5229
  _VERBS._serialized_start=5231
  _VERBS._serialized_end=5253
  _WATCHEVENT._serialized_start=5255
  _WATCHEVENT._serialized_end=5344
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.runbook.v1 import runbook_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2


class RunBookServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListRunBooks = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/ListRunBooks',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.ListRunBooksRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.ListRunBooksResponse.FromString,
                )
        self.CreateRunBook = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/CreateRunBook',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.CreateRunBookRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.CreateRunBookResponse.FromString,
                )
        self.GetRunBook = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/GetRunBook',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.GetRunBookRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.GetRunBookResponse.FromString,
                )
        self.UpdateRunBook = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/UpdateRunBook',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.UpdateRunBookRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.UpdateRunBookResponse.FromString,
                )
        self.DeleteRunBook = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/DeleteRunBook',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.DeleteRunBookRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.DeleteRunBookResponse.FromString,
                )


class RunBookServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListRunBooks(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRunBook(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRunBook(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRunBook(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRunBook(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RunBookServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListRunBooks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRunBooks,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.ListRunBooksRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.ListRunBooksResponse.SerializeToString,
            ),
            'CreateRunBook': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRunBook,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.CreateRunBookRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.CreateRunBookResponse.SerializeToString,
            ),
            'GetRunBook': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRunBook,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.GetRunBookRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.GetRunBookResponse.SerializeToString,
            ),
            'UpdateRunBook': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRunBook,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.UpdateRunBookRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.UpdateRunBookResponse.SerializeToString,
            ),
            'DeleteRunBook': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRunBook,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.DeleteRunBookRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.DeleteRunBookResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.runbook.v1.RunBookService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RunBookService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListRunBooks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/ListRunBooks',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.ListRunBooksRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.ListRunBooksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateRunBook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/CreateRunBook',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.CreateRunBookRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.CreateRunBookResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRunBook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/GetRunBook',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.GetRunBookRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.GetRunBookResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateRunBook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/UpdateRunBook',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.UpdateRunBookRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.UpdateRunBookResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteRunBook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/DeleteRunBook',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.DeleteRunBookRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.DeleteRunBookResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



__author__ = """Chris Tabor (dxdstudio@gmail.com)"""


from os import walk
from os import getcwd
from os import path
from os import sys
from glob import glob

sys.path.append(getcwd())


def packagify():
    paths = []
    start_dir = "github"
    pattern = "*.py"
    for dir, subdirs, files in walk(start_dir):
        # Needs to handle ignored directories
        print(dir, subdirs, files)
        if '__init__.py' not in files or len(files) == 0:
            with open('{}/__init__.py'.format(dir), 'wb+') as initfile:
                initfile.write(b'\n')
        paths.extend(glob(path.join(dir, pattern)))
    return paths



packagify()